| Home | Libraries | People | FAQ | More

### sinc_pi

    #include <boost/math/special_functions/sinc.hpp>

    template<class T>
    calculated-result-type sinc_pi(const T x);

    template<class T, class Policy>
    calculated-result-type sinc_pi(const T x, const Policy&);

    template<class T, template<typename> class U>
    U<T> sinc_pi(const U<T> x);

    template<class T, template<typename> class U, class Policy>
    U<T> sinc_pi(const U<T> x, const Policy&);

Computes the Sinus Cardinal of x:

> sinc_pi(x) = sin(x) / x

The second form is for complex numbers, quaternions, octonions etc. Taylor series are used at the origin to ensure accuracy.

The final Policy argument is optional and can be used to control the behaviour of the function: how it handles errors, what level of precision to use etc. Refer to the policy documentation for more details.